Downstream proxying from TCP clients to iroh endpoints.
Structs
- Deny
- Request rejection with HTTP status code and reason.
- Downstream
Metrics - Downstream
Proxy - Proxy that accepts TCP connections and forwards them over iroh.
- Endpoint
Authority - Routing destination combining an iroh endpoint and target authority.
- Http
Proxy Opts - Configuration for HTTP proxy mode.
- Pool
Opts - Configuration for the upstream connection pool.
- Proxy
Error - Error from downstream proxy operations.
- Request
Handler Chain - Chains multiple request handlers, trying each in order.
- Static
Forward Proxy - Forward proxy handler that routes all requests to a fixed endpoint.
- Static
Reverse Proxy - Reverse proxy handler that routes all requests to a fixed backend.
- Tunnel
Client Streams - Bidirectional QUIC streams for an established tunnel.
Enums
- Proxy
Mode - Operating mode for the downstream proxy.
- SrcAddr
- Source address for downstream client streams.
Traits
- Error
Responder - Generates HTTP error responses for proxy failures.
- Request
Handler - Routes HTTP requests to upstream iroh endpoints.