pub enum HttpProxyRequestKind {
Tunnel {
target: Authority,
},
Absolute {
target: Uri,
method: Method,
},
}Expand description
Proxy-specific request target classification (RFC 9110 7.1).
Distinguishes between CONNECT tunneling and absolute-form forwarding, both of which are valid for forward proxies.
Variants
Tunnel
CONNECT tunnel request with authority-form target.
Absolute
Forward proxy request with absolute-form target.
Implementations
Sourceimpl HttpProxyRequestKind
impl HttpProxyRequestKind
Returns the Authority for this request.
Returns an error if the absolute-form URI does not contain a port and does not have an HTTP(s) scheme.